aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Updates/VersionInfo.cs
diff options
context:
space:
mode:
authorJoshua M. Boniface <joshua@boniface.me>2020-12-31 18:47:05 -0500
committerJoshua M. Boniface <joshua@boniface.me>2020-12-31 18:49:53 -0500
commit1ad8e540353701555aeb483ccd4e9edad460e7d8 (patch)
treece51ff3860d69b7ee23e82e671a034aa3d4661e9 /MediaBrowser.Model/Updates/VersionInfo.cs
parent83dd3e22018d8b9065137c5444b3027f90ee0ae8 (diff)
Merge pull request #4709 from BaronGreenback/PluginDowngrade
(cherry picked from commit 406ae3e43a20216292c554151fa2d0e2a09edfa3) Signed-off-by: Joshua M. Boniface <joshua@boniface.me>
Diffstat (limited to 'MediaBrowser.Model/Updates/VersionInfo.cs')
-rw-r--r--MediaBrowser.Model/Updates/VersionInfo.cs47
1 files changed, 25 insertions, 22 deletions
diff --git a/MediaBrowser.Model/Updates/VersionInfo.cs b/MediaBrowser.Model/Updates/VersionInfo.cs
index 844170999a..209092265e 100644
--- a/MediaBrowser.Model/Updates/VersionInfo.cs
+++ b/MediaBrowser.Model/Updates/VersionInfo.cs
@@ -1,76 +1,79 @@
-#nullable disable
+#nullable enable
-using System;
+using System.Text.Json.Serialization;
+using SysVersion = System.Version;
namespace MediaBrowser.Model.Updates
{
/// <summary>
- /// Class PackageVersionInfo.
+ /// Defines the <see cref="VersionInfo"/> class.
/// </summary>
public class VersionInfo
{
- private Version _version;
+ private SysVersion? _version;
/// <summary>
/// Gets or sets the version.
/// </summary>
/// <value>The version.</value>
- public string version
+ [JsonPropertyName("version")]
+ public string Version
{
- get
- {
- return _version == null ? string.Empty : _version.ToString();
- }
+ get => _version == null ? string.Empty : _version.ToString();
- set
- {
- _version = Version.Parse(value);
- }
+ set => _version = SysVersion.Parse(value);
}
/// <summary>
/// Gets the version as a <see cref="Version"/>.
/// </summary>
- public Version VersionNumber => _version;
+ public SysVersion VersionNumber => _version ?? new SysVersion(0, 0, 0);
/// <summary>
/// Gets or sets the changelog for this version.
/// </summary>
/// <value>The changelog.</value>
- public string changelog { get; set; }
+ [JsonPropertyName("changelog")]
+ public string? Changelog { get; set; }
/// <summary>
/// Gets or sets the ABI that this version was built against.
/// </summary>
/// <value>The target ABI version.</value>
- public string targetAbi { get; set; }
+ [JsonPropertyName("targetAbi")]
+ public string? TargetAbi { get; set; }
/// <summary>
/// Gets or sets the source URL.
/// </summary>
/// <value>The source URL.</value>
- public string sourceUrl { get; set; }
+ [JsonPropertyName("sourceUrl")]
+ public string? SourceUrl { get; set; }
/// <summary>
/// Gets or sets a checksum for the binary.
/// </summary>
/// <value>The checksum.</value>
- public string checksum { get; set; }
+ [JsonPropertyName("checksum")]
+ public string? Checksum { get; set; }
/// <summary>
/// Gets or sets a timestamp of when the binary was built.
/// </summary>
/// <value>The timestamp.</value>
- public string timestamp { get; set; }
+ [JsonPropertyName("timestamp")]
+ public string? Timestamp { get; set; }
/// <summary>
/// Gets or sets the repository name.
/// </summary>
- public string repositoryName { get; set; }
+ [JsonPropertyName("repositoryName")]
+ public string RepositoryName { get; set; } = string.Empty;
/// <summary>
/// Gets or sets the repository url.
/// </summary>
- public string repositoryUrl { get; set; }
+ [JsonPropertyName("repositoryUrl")]
+ public string RepositoryUrl { get; set; } = string.Empty;
}
}
@@ -1,76 +1,79 @@
}
/// <summary>
- /// Gets the version as a <see cref="Version"/>.
+ /// Gets the version as a <see cref="SysVersion"/>.
/// </summary>